@@ -241,6 +241,41 @@ class BaseConnectionConfig(
 ConnectionConfigT = TypeVar("ConnectionConfigT", bound=BaseConnectionConfig)
 
 
+class MySQLConnectionConfig(
+    BaseConnectionConfig[Literal[Driver.MYSQL], str, str, str, int, str]
+):
+    driver: Literal[Driver.MYSQL] = Driver.MYSQL
+    port: int = Field(3306, description="MySQL port")
+    username: str = Field("root", description="MySQL username")
+
+    # MySQL-specific options
+    echo: bool = Field(False, description="Enable SQL statement logging")
+    charset: MySQLCharset = Field(MySQLCharset.UTF8MB4, description="Character set")
+
+    def _make_mysql_url(self, connection: Connection = Connection.ASYNC) -> str:
+        """MySQL database URL format with proper async/sync drivers."""
+        # Choose appropriate driver based on connection type
+        if connection is Connection.ASYNC:
+            driver_name = "mysql+aiomysql"
+        elif connection is Connection.SYNC:
+            driver_name = "mysql+pymysql"  # or mysqlclient
+        else:
+            driver_name = "mysql"  # Default
+
+        encoded_user = self._safe_encode_credential(self.username)
+        encoded_pass = self._safe_encode_credential(self.password)
+
+        base_url = f"{driver_name}://{encoded_user}:{encoded_pass}@{self.host}:{self.port}/{self.database}"
+
+        # Add MySQL-specific options
+        mysql_options = {"charset": self.charset}
+        return base_url + self._make_options_string(mysql_options)
+
+    @property
+    def engine_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(include={"echo"}, exclude_none=True)
+
+
 class PostgreSQLConnectionConfig(
     BaseConnectionConfig[Literal[Driver.POSTGRESQL], str, str, str, int, str]
 ):
@@ -279,36 +314,9 @@ class PostgreSQLConnectionConfig(
 
         return base_url + self._make_options_string(pg_options)
 
-
-class MySQLConnectionConfig(
-    BaseConnectionConfig[Literal[Driver.MYSQL], str, str, str, int, str]
-):
-    driver: Literal[Driver.MYSQL] = Driver.MYSQL
-    port: int = Field(3306, description="MySQL port")
-    username: str = Field("root", description="MySQL username")
-
-    # MySQL-specific options
-    echo: bool = Field(False, description="Enable SQL statement logging")
-    charset: MySQLCharset = Field(MySQLCharset.UTF8MB4, description="Character set")
-
-    def _make_mysql_url(self, connection: Connection = Connection.ASYNC) -> str:
-        """MySQL database URL format with proper async/sync drivers."""
-        # Choose appropriate driver based on connection type
-        if connection is Connection.ASYNC:
-            driver_name = "mysql+aiomysql"
-        elif connection is Connection.SYNC:
-            driver_name = "mysql+pymysql"  # or mysqlclient
-        else:
-            driver_name = "mysql"  # Default
-
-        encoded_user = self._safe_encode_credential(self.username)
-        encoded_pass = self._safe_encode_credential(self.password)
-
-        base_url = f"{driver_name}://{encoded_user}:{encoded_pass}@{self.host}:{self.port}/{self.database}"
-
-        # Add MySQL-specific options
-        mysql_options = {"charset": self.charset}
-        return base_url + self._make_options_string(mysql_options)
+    @property
+    def engine_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(include={"echo"}, exclude_none=True)
 
 
 class SQLiteConnectionConfig(
@@ -339,6 +347,10 @@ class SQLiteConnectionConfig(
         base_url = f"{driver_name}:///{self.database}"
         return base_url + self._make_options_string()
 
+    @property
+    def engine_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(include={"echo"}, exclude_none=True)
+
 
 class SQLServerConnectionConfig(
     BaseConnectionConfig[Literal[Driver.MSSQL], str, str, str, int, str]
@@ -392,6 +404,10 @@ class SQLServerConnectionConfig(
         }
         return base_url + self._make_options_string(mssql_options)
 
+    @property
+    def engine_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(include={"echo"}, exclude_none=True)
+
 
 class MongoDBConnectionConfig(
     BaseConnectionConfig[
